@@ -1,8 +1,11 @@
 import pandas as pd
 
-from ._constants import ESTIMATED_COLUMN_NAME, OBSERVED_COLUMN_NAME
-from ._get_ranges import _get_ranges
-from ._types import RangeObject
+from woodwork.statistics_utils.frequency_inference._constants import (
+    ESTIMATED_COLUMN_NAME,
+    OBSERVED_COLUMN_NAME,
+)
+from woodwork.statistics_utils.frequency_inference._get_ranges import _get_ranges
+from woodwork.statistics_utils.frequency_inference._types import RangeObject
 
 
 def _determine_missing_values(estimated_ts, observed_ts):
