@@ -32,7 +32,12 @@ from woodwork.logical_types import (
     PostalCode,
     SubRegionCode,
 )
-from woodwork.tests.testing_utils import is_property, is_public_method, to_pandas
+from woodwork.tests.testing_utils import (
+    concat_dataframe_or_series,
+    is_property,
+    is_public_method,
+    to_pandas,
+)
 from woodwork.utils import import_or_none
 
 dd = import_or_none("dask.dataframe")
@@ -163,7 +168,7 @@ def test_accessor_init_with_invalid_logical_type(sample_series):
     correct_dtype = "string"
     error_message = re.escape(
         f"Cannot initialize Woodwork. Series dtype '{series_dtype}' is incompatible with "
-        f"NaturalLanguage dtype. Try converting series dtype to '{correct_dtype}' before "
+        f"NaturalLanguage LogicalType. Try converting series dtype to '{correct_dtype}' before "
         "initializing or use the woodwork.init_series function to initialize.",
     )
     with pytest.raises(TypeValidationError, match=error_message):
@@ -1025,7 +1030,7 @@ def test_validate_logical_type(sample_df):
     if _is_spark_series(series):
         invalid_row = ps.from_pandas(invalid_row)
 
-    series = series.append(invalid_row)
+    series = concat_dataframe_or_series(series, invalid_row)
     series = init_series(series, logical_type="EmailAddress")
     match = "Series email contains invalid email address values. "
     match += "The email_inference_regex can be changed in the config if needed."
