@@ -30,7 +30,10 @@ from woodwork.logical_types import (
     PostalCode,
     _replace_nans,
 )
-from woodwork.tests.testing_utils.table_utils import to_pandas
+from woodwork.tests.testing_utils.table_utils import (
+    concat_dataframe_or_series,
+    to_pandas,
+)
 from woodwork.utils import import_or_none
 
 ps = import_or_none("pyspark.pandas")
@@ -268,7 +271,7 @@ def test_ordinal_validate(sample_series):
 
     new_type = "string"
     error_message = re.escape(
-        f"Series dtype '{new_type}' is incompatible with ordinal dtype.",
+        f"Series dtype '{new_type}' is incompatible with ordinal LogicalType, try converting to category dtype",
     )
     with pytest.raises(TypeValidationError, match=error_message):
         ordinal_incomplete_order.validate(sample_series.astype(new_type))
@@ -285,7 +288,8 @@ def test_email_address_validate(sample_df):
 
     assert email_address.validate(series) is None
 
-    series = series.append(invalid_row).astype(dtype)
+    series = concat_dataframe_or_series(series, invalid_row).astype(dtype)
+
     match = "Series email contains invalid email address values. "
     match += "The email_inference_regex can be changed in the config if needed."
 
@@ -307,7 +311,8 @@ def test_url_validate(sample_df):
 
     assert logical_type.validate(series) is None
 
-    series = series.append(invalid_row).astype(dtype)
+    series = concat_dataframe_or_series(series, invalid_row).astype(dtype)
+
     match = "Series url contains invalid url values. "
     match += "The url_inference_regex can be changed in the config if needed."
 
@@ -337,7 +342,8 @@ def test_age_validate(sample_df, logical_type):
 
     if _is_spark_series(series):
         invalid_row = ps.from_pandas(invalid_row)
-    series = series.append(invalid_row).astype(dtype)
+
+    series = concat_dataframe_or_series(series, invalid_row).astype(dtype)
 
     match = "Series age contains negative values."
     with pytest.raises(TypeValidationError, match=match):
@@ -358,7 +364,8 @@ def test_phone_number_validate(sample_df):
 
     assert phone_number.validate(series) is None
 
-    series = series.append(invalid_row).astype(dtype)
+    series = concat_dataframe_or_series(series, invalid_row).astype(dtype)
+
     match = "Series phone_number contains invalid phone number values. "
     match += "The phone_inference_regex can be changed in the config if needed."
 
@@ -380,7 +387,8 @@ def test_phone_number_validate_complex(sample_df_phone_numbers):
         name="phone_number",
     ).astype(dtype)
 
-    series = series.append(invalid_row).astype(dtype)
+    series = concat_dataframe_or_series(series, invalid_row).astype(dtype)
+
     actual = phone_number.validate(series, return_invalid_values=True)
     expected = pd.Series(
         {17: "252 9384", 18: "+1 194 129 1991", 19: "+01 236 248 8482"},
@@ -399,7 +407,9 @@ def test_postal_code_validate(sample_df_postal_code):
             "51342-HEL0",
         ],
     )
-    series = series.append(invalid_types)
+
+    series = concat_dataframe_or_series(series, invalid_types)
+
     series.name = "postal_code"
     match = "Series postal_code contains invalid postal code values. "
     match += "The postal_code_inference_regex can be changed in the config if needed."
@@ -427,7 +437,9 @@ def test_postal_code_validate_complex(sample_df_postal_code):
     )
     actual = pc.validate(series, return_invalid_values=True)
     assert not len(actual)
-    series = series.append(invalid_types)
+
+    series = concat_dataframe_or_series(series, invalid_types)
+
     actual = pc.validate(series, return_invalid_values=True)
     pd.testing.assert_series_equal(actual, invalid_types)
 
@@ -446,7 +458,10 @@ def test_postal_code_validate_numeric(postal_code_numeric_series):
 
 
 def test_postal_code_error(postal_code_numeric_series_pandas):
-    series = postal_code_numeric_series_pandas.append(pd.Series([1234.5]))
+    series = concat_dataframe_or_series(
+        postal_code_numeric_series_pandas,
+        pd.Series([1234.5]),
+    )
     match = (
         "Error converting datatype for None from type float64 to type string. "
         "Please confirm the underlying data is consistent with logical type PostalCode."
@@ -917,3 +932,131 @@ def test_datetime_pivot_point_no_format_provided():
     df_expected = pd.DataFrame({"dates": expected_values}, dtype="datetime64[ns]")
     df.ww.init(logical_types={"dates": Datetime})
     pd.testing.assert_frame_equal(df, df_expected)
+
+
+@pytest.mark.parametrize("df_type", ["pandas", "dask", "spark"])
+def test_boolean_other_values(df_type):
+    df = pd.DataFrame(
+        {
+            "bool1": [0, 1, 0, 1, 1, 0],
+            "bool2": ["t", "f", "t", "f", "t", "t"],
+            "bool3": ["T", "F", "T", "F", "F", "f"],
+            "bool4": ["true", "false", "false", "false", "true", "true"],
+            "bool5": ["True", "False", "False", "True", "false", "TRUE"],
+            "bool6": ["1", "0", "1", "1", "1", "0"],
+            "bool7": ["1.0", "0.0", "1.0", "1.0", "1.0", "0.0"],
+            "bool8": ["YES", "NO", "YES", "yes", "no", "no"],
+            "bool9": ["N", "N", "n", "y", "Y", "y"],
+        },
+    )
+    if df_type == "spark":
+        ps = pytest.importorskip(
+            "pyspark.pandas",
+            reason="Pyspark pandas not installed, skipping",
+        )
+        df = ps.from_pandas(df)
+    elif df_type == "dask":
+        dd = pytest.importorskip(
+            "dask.dataframe",
+            reason="Dask not installed, skipping",
+        )
+        df = dd.from_pandas(df, npartitions=1)
+    df.ww.init()
+    assert all([str(dtype) == "Boolean" for dtype in df.ww.logical_types.values()])
+
+
+def test_boolean_cast_nulls_as():
+    Boolean(cast_nulls_as=None)
+    Boolean(cast_nulls_as=False)
+    Boolean(cast_nulls_as=True)
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            f"Parameter `cast_nulls_as` must be either True or False, recieved {1}",
+        ),
+    ):
+        Boolean(cast_nulls_as=1)
+    with pytest.raises(
+        ValueError,
+        match=re.escape(
+            f"Parameter `cast_nulls_as` must be either True or False, recieved {'True'}",
+        ),
+    ):
+        Boolean(cast_nulls_as="True")
+
+
+@pytest.mark.parametrize("cast_null", [None, True, False])
+@pytest.mark.parametrize("null", [None, pd.NA, np.nan])
+@pytest.mark.parametrize(
+    "series",
+    (
+        [True, True, False, False],
+        ["Yes", "yes", "NO", "no"],
+        ["1", "1", "0", "0"],
+        ["True", "true", "false", "FALSE"],
+    ),
+)
+def test_boolean_with_null_error(series, null, cast_null):
+    df = pd.DataFrame({"bool_with_null": series + [null]})
+    if cast_null is None:
+        with pytest.raises(
+            ValueError,
+            match="Expected no null values in this Boolean column. If you want to keep the nulls, use BooleanNullable type. Otherwise, cast these nulls to a boolean value",
+        ):
+            df.ww.init(
+                logical_types={"bool_with_null": Boolean(cast_nulls_as=cast_null)},
+            )
+    else:
+        df.ww.init(logical_types={"bool_with_null": Boolean(cast_nulls_as=cast_null)})
+        assert list(df["bool_with_null"].values) == [
+            True,
+            True,
+            False,
+            False,
+            cast_null,
+        ]
+
+
+@pytest.mark.parametrize("df_type", ["pandas", "dask", "spark"])
+@pytest.mark.parametrize("null", [None, pd.NA, np.nan])
+def test_boolean_nullable_other_values_dont_cast(null, df_type):
+    df = pd.DataFrame(
+        {
+            "bool1": ["N", "N", "n", null, "Y", "y"],
+            "bool2": ["t", "f", "t", null, "f", "t"],
+            "bool3": ["T", "F", "T", "F", "F", null],
+            "bool4": ["true", "false", "false", "false", "true", null],
+            "bool5": ["True", "False", "False", "True", null, "TRUE"],
+            "bool6": ["1", "0", "1", null, "1", "0"],
+            "bool7": ["YES", "NO", "YES", "yes", null, "no"],
+        },
+    )
+    if df_type == "spark":
+        ps = pytest.importorskip(
+            "pyspark.pandas",
+            reason="Pyspark pandas not installed, skipping",
+        )
+        df = ps.from_pandas(df)
+    elif df_type == "dask":
+        dd = pytest.importorskip(
+            "dask.dataframe",
+            reason="Dask not installed, skipping",
+        )
+        df = dd.from_pandas(df, npartitions=1)
+    df.ww.init()
+    assert all(
+        [str(dtype) == "BooleanNullable" for dtype in df.ww.logical_types.values()],
+    )
+
+
+def test_boolean_mixed_string():
+    df = pd.DataFrame(
+        {
+            "a": ["yes", "y", "n", "n"],
+            "b": ["True", "t", "False", "False"],
+            "c": ["0", "y", "0", "y"],
+        },
+    )
+
+    df.ww.init()
+    assert all([str(dtype) != "Boolean" for dtype in df.ww.logical_types.values()])
