@@ -1,3 +1,5 @@
+import sys
+
 import numpy as np
 import pandas as pd
 import pytest
@@ -9,7 +11,7 @@ from woodwork.type_sys.inference_functions import (
     double_func,
     integer_func,
 )
-from woodwork.type_sys.type_system import TypeSystem
+from woodwork.type_sys.type_system import INFERENCE_SAMPLE_SIZE, TypeSystem
 
 
 # Integer Inference Fixtures
@@ -18,6 +20,7 @@ def pandas_integers():
     return [
         pd.Series(4 * [-1, 2, 1, 7]),
         pd.Series(4 * [-1, 0, 5, 3]),
+        pd.Series(4 * [sys.maxsize, -sys.maxsize - 1, 0], dtype="str").astype("int64"),
     ]
 
 
@@ -39,7 +42,12 @@ def integers(request):
 # Double Inference Fixtures
 @pytest.fixture
 def pandas_doubles():
-    return [pd.Series(4 * [-1, 2.5, 1, 7]), pd.Series(4 * [1.5, np.nan, 1, 3])]
+    return [
+        pd.Series(4 * [-1, 2.5, 1, 7]),
+        pd.Series(4 * [1.5, np.nan, 1, 3]),
+        pd.Series(4 * [1.5, np.inf, 1, 3]),
+        pd.Series(4 * [np.finfo("d").max, np.finfo("d").min, 3, 1]),
+    ]
 
 
 @pytest.fixture
@@ -63,6 +71,17 @@ def pandas_bools():
     return [
         pd.Series([True, False, True, True]),
         pd.Series([True, np.nan, True, True]),
+        pd.Series([1, 0, 0, 1]),
+        pd.Series(["y", "n", "N", "Y"]),
+        pd.Series(["True", "false", "FALSE", "TRUE"]),
+        pd.Series(["t", "f", "T", "T"]),
+        pd.Series(["yes", "no", "NO", "Yes"]),
+        pd.Series(["1", "1", "1", "0"]),
+        pd.Series(["y", "n", "N", None]),
+        pd.Series(["True", "false", pd.NA, "TRUE"]),
+        pd.Series(["t", "f", "T", np.nan]),
+        pd.Series(["yes", "no", "NO", pd.NA]),
+        pd.Series(["1", "1", np.nan, "0"]),
     ]
 
 
@@ -263,6 +282,33 @@ def natural_language(request):
     return request.getfixturevalue(request.param)
 
 
+# Postal Inference Fixtures
+@pytest.fixture
+def pandas_postal_codes():
+    return [
+        pd.Series(10 * ["77002", "55106"]),
+        pd.Series(10 * ["77002-0000", "55106-0000"]),
+        pd.Series(10 * ["12345", "12345", "12345-6789", "12345-0000"]),
+    ]
+
+
+@pytest.fixture
+def dask_postal_codes(pandas_postal_codes):
+    return [pd_to_dask(series) for series in pandas_postal_codes]
+
+
+@pytest.fixture
+def spark_postal_codes(pandas_postal_codes):
+    return [pd_to_spark(series) for series in pandas_postal_codes]
+
+
+@pytest.fixture(
+    params=["pandas_postal_codes", "dask_postal_codes", "spark_postal_codes"],
+)
+def postal(request):
+    return request.getfixturevalue(request.param)
+
+
 # Unknown Inference Fixtures
 @pytest.fixture
 def pandas_strings():
@@ -270,6 +316,9 @@ def pandas_strings():
         pd.Series(
             ["Mr. John Doe", "Doe, Mrs. Jane", "James Brown", "Ms. Paige Turner"],
         ),
+        pd.Series(["y", "no", "N", None]),
+        pd.Series(["T", "false", pd.NA, "TRUE"]),
+        pd.Series(["1", "1", np.nan, "0.0"]),
     ]
 
 
@@ -318,6 +367,29 @@ def pdnas(request):
     return request.getfixturevalue(request.param)
 
 
+# Empty Series Inference Fixtures
+@pytest.fixture
+def pandas_empty_series():
+    return pd.Series([], dtype="object")
+
+
+@pytest.fixture
+def dask_empty_series(pandas_empty_series):
+    return pd_to_dask(pandas_empty_series)
+
+
+@pytest.fixture
+def pyspark_empty_series(pandas_empty_series):
+    return pd_to_spark(pandas_empty_series)
+
+
+@pytest.fixture(
+    params=["pandas_empty_series", "dask_empty_series", "pyspark_empty_series"],
+)
+def empty_series(request):
+    return request.getfixturevalue(request.param)
+
+
 # Null Inference Fixtures
 @pytest.fixture
 def pandas_nulls():
@@ -345,6 +417,31 @@ def nulls(request):
     return request.getfixturevalue(request.param)
 
 
+@pytest.fixture
+def pandas_large_df():
+    df = pd.DataFrame()
+    df["int_nullable"] = [int(i) for i in range(INFERENCE_SAMPLE_SIZE)] + [np.nan]
+    df["bool_nullable"] = [True, False] * int(INFERENCE_SAMPLE_SIZE // 2) + [pd.NA]
+    df["floats"] = [int(i) for i in range(INFERENCE_SAMPLE_SIZE)] + [1.2]
+    df["constant"] = [None] * (INFERENCE_SAMPLE_SIZE + 1)
+    return df
+
+
+@pytest.fixture
+def dask_large_df(pandas_large_df):
+    return pd_to_dask(pandas_large_df)
+
+
+@pytest.fixture
+def spark_large_df(pandas_large_df):
+    return pd_to_spark(pandas_large_df)
+
+
+@pytest.fixture(params=["pandas_large_df", "dask_large_df", "spark_large_df"])
+def large_df(request):
+    return request.getfixturevalue(request.param)
+
+
 @pytest.fixture
 def default_inference_functions():
     return {
