@@ -13,7 +13,9 @@ def test_register_custom_logical_type(type_sys):
         return True
 
     type_sys.add_type(
-        CustomLogicalType, inference_function=custom_func, parent="Categorical"
+        CustomLogicalType,
+        inference_function=custom_func,
+        parent="Categorical",
     )
     assert CustomLogicalType in type_sys.registered_types
     assert (Categorical, CustomLogicalType) in type_sys.relationships
@@ -35,7 +37,9 @@ def test_custom_type_with_accessor(sample_df):
         return False
 
     ww.type_system.add_type(
-        AgesAbove20, inference_function=ages_func, parent="IntegerNullable"
+        AgesAbove20,
+        inference_function=ages_func,
+        parent="IntegerNullable",
     )
     sample_df.ww.init()
     assert isinstance(sample_df.ww["age"].ww.logical_type, AgesAbove20)
@@ -47,17 +51,18 @@ def test_custom_type_with_accessor(sample_df):
 
 def test_accessor_override_default_function(sample_df):
     def new_double_func(series):
-        if pdtypes.is_integer_dtype(series.dtype):
+        if pdtypes.is_bool_dtype(series.dtype):
             return True
         return False
 
-    # Update functions to cause 'age' to be recognized as Double instead fo Integer
+    # Update functions to cause 'is_registered' to be recognized as Double instead fo BooleanNullable
     ww.type_system.update_inference_function(
-        "Double", inference_function=new_double_func
+        "Double",
+        inference_function=new_double_func,
     )
-    ww.type_system.update_inference_function("Integer", inference_function=None)
+    ww.type_system.update_inference_function("BooleanNullable", inference_function=None)
     sample_df.ww.init()
-    assert isinstance(sample_df.ww["age"].ww.logical_type, Double)
-    assert sample_df["age"].dtype == "float64"
+    assert isinstance(sample_df.ww["is_registered"].ww.logical_type, Double)
+    assert sample_df["is_registered"].dtype == "float64"
     # Reset global type system to original settings
     ww.type_system.reset_defaults()
