@@ -1,3 +1,4 @@
+import sys
 from importlib import resources as pkg_resources
 from typing import Any, Callable, Iterable, Union
 
@@ -7,8 +8,11 @@ from pandas.api import types as pdtypes
 
 import woodwork as ww
 from woodwork import data
+from woodwork.config import config
 from woodwork.type_sys.utils import _is_categorical_series, col_is_datetime
 
+MAX_INT = sys.maxsize
+MIN_INT = -sys.maxsize - 1
 Tokens = Iterable[str]
 
 COMMON_WORDS_SET = set(
@@ -53,10 +57,14 @@ def integer_nullable_func(series):
         else:
             return True
     elif pdtypes.is_float_dtype(series.dtype):
+
+        def _is_valid_int(value):
+            return value >= MIN_INT and value <= MAX_INT and value.is_integer()
+
         if not series.isnull().any():
             return False
         series_no_null = series.dropna()
-        return all(series_no_null.mod(1).eq(0))
+        return all([_is_valid_int(v) for v in series_no_null])
 
     return False
 
@@ -93,8 +101,18 @@ def boolean_nullable_func(series):
                 {False},
             ]:
                 return True
+            series_lower = set(str(s).lower() for s in set(series_no_null))
+            if series_lower in [
+                set(boolean_list)
+                for boolean_list in config.get_option("boolean_inference_strings")
+            ]:
+                return True
         except TypeError:  # Necessary to check for non-hashable values because of object dtype consideration
             return False
+    elif pdtypes.is_integer_dtype(series.dtype):
+        series_unique = set(series)
+        if series_unique == set(config.get_option("boolean_inference_ints")):
+            return True
     return False
 
 
@@ -138,7 +156,10 @@ class InferWithRegex:
         regex = self.get_regex()
 
         # Includes a check for object dtypes
-        if not pdtypes.is_string_dtype(series.dtype):
+        if not (
+            pdtypes.is_categorical_dtype(series.dtype)
+            or pdtypes.is_string_dtype(series.dtype)
+        ):
             return False
 
         try:
